#include <iostream>
#include <vector>

using namespace std;

const size_t SCREEN_WIDTH = 80;
const size_t MAX_ASTERISK = SCREEN_WIDTH - 3 - 1;

struct Input
{
    vector<double> numbers;
    size_t bin_count{};
};

Input input_data()
{

    size_t number_count, bin_count;

    cerr << "Enter number count: ";
    cin >> number_count;

    Input in;
    in.numbers.resize(number_count);

    cerr << "Enter numbers: ";

    for (size_t i = 0; i < number_count; i++)
    {
        cin >> in.numbers[i];
    }

    cerr << "Enter number of bins: ";
    cin >> in.bin_count;

    return in;
}

void find_minmax(const vector<double> &numbers, double &min, double &max)
{
    min = numbers[0];
    for (double x : numbers)
    {
        if (x < min)
        {
            min = x;
        }
        else if (x > max)
        {
            max = x;
        }
    }
}

vector<int> make_histogram(const vector<double> &numbers, size_t bin_count)
{
    vector<int> bins(bin_count);
    int max_count = bins[0];
    double min = numbers[0];
    double max = numbers[0];

    find_minmax(numbers, min, max);
    double bin_size = (max - min) / bin_count;

    for (size_t i = 0; i < numbers.size(); i++)
    {
        bool found = false;
        for (size_t j = 0; (j < bin_count - 1) && !found; j++)
        {
            auto lo = min + j * bin_size;
            auto hi = min + (j + 1) * bin_size;

            if ((lo <= numbers[i]) && (numbers[i] < hi))
            {
                bins[j]++;
                found = true;
            }
        }

        if (!found)
        {
            bins[bin_count - 1]++;
        }
    }
    return bins;
}

void show_histogram_text(vector<int> &bins, size_t bin_count)
{
    int max_count = bins[0];
    for (int i = 0; i < bin_count; i++)
    {
        if (bins[i] > max_count)
        {
            max_count = bins[i];
        }
    }
    vector<double> height(bin_count);
    for (int i = 0; i < bin_count; i++)
    {
        if (bins[i] > MAX_ASTERISK)
        {
            height[i] = (MAX_ASTERISK * bins[i]) / max_count;
        }
        else
            height[i] = bins[i];
    }

    for (int i = 0; i < bin_count; i++)
    {

        if (bins[i] < 100)
        {
            cout << " ";
        }

        if (bins[i] < 10)
        {
            cout << " ";
        }

        cout << bins[i] << "|";

        for (int j = 0; j < height[i]; j++)
        {
            cout << "*";
        }
        cout << endl;
    }
}

int main()
{
    auto in = input_data();
    auto bins = make_histogram(in.numbers, in.bin_count);
    show_histogram_text(bins, in.bin_count);
    return 0;
}